@@ -113,7 +113,7 @@ pub fn cmd_run(
             debug!("extract cache");
             cache_drive
                 .extract_to(&cachedir)
-                .map_err(|e| QemuError::ExtractCache(cachedir.clone(), e))?;
+                .map_err(|e| QemuError::ExtractCache(cachedir.clone(), Box::new(e)))?;
 
             debug!("Executing post-plan steps");
             let post_plan = runnable_plan_from_trusted_actions(
@@ -286,7 +286,7 @@ fn create_tar(tar_filename: PathBuf, dirname: &Path) -> Result<VirtualDrive, Qem
         .filename(&tar_filename)
         .root_directory(dirname)
         .create()
-        .map_err(|e| QemuError::Tar(dirname.into(), e))?;
+        .map_err(|e| QemuError::Tar(dirname.into(), Box::new(e)))?;
     Ok(tar)
 }
 
@@ -300,7 +300,7 @@ fn create_tar_with_size(
         .root_directory(dirname)
         .size(size)
         .create()
-        .map_err(|e| QemuError::Tar(dirname.into(), e))?;
+        .map_err(|e| QemuError::Tar(dirname.into(), Box::new(e)))?;
 
     let metadata = std::fs::metadata(&tar_filename)
         .map_err(|err| QemuError::Metadata(tar_filename.clone(), err))?;
